@@ -3,7 +3,7 @@
 from .abstractnode import AbstractNode
 from .triple import Triple
 from .missing import Missing
-from .resource import Resource
+from .resource import *
 from .sentence import Sentence
 from .list import List
 from .list_operators import Union, Intersection, And, Or, First, Last, Sort
